==> ejc-assistrmat-impl-3.0.0-20220414.072742-68-sources.jar: com/ejianc/business/assist/material/bean/MaterialBatchPlanDetailEntity.java <==
package com.ejianc.business.assist.material.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 周转材采购申请-清单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_assistmaterial_batch_plan_detail")
public class MaterialBatchPlanDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="batch_id")
    private Long batchId; // 批次计划主键
    @TableField(value="material_type_id")
    private Long materialTypeId; // 材料分类id
    @TableField(value="material_type_name")
    private String materialTypeName; // 材料分类名称
    @TableField(value="material_type_code")
    private String materialTypeCode; // 材料分类编码
    @TableField(value="material_id")
    private Long materialId; // 材料id
    @TableField(value="material_name")
    private String materialName; // 材料名称
    @TableField(value="material_code")
    private String materialCode; // 材料编码
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit")
    private String unit; // 计量单位
    @TableField(value="num")
    private BigDecimal num; // 计划总量
    @TableField(value="mny")
    private BigDecimal mny; // 暂估金额
    @TableField(value="plan_use_time")
    private Date planUseTime; // 计划开始使用时间
    @TableField(value="standard")
    private String standard; // 质量验收标准或要求
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="source_id")
    private Long sourceId; // 物资来源出业务Id
    @TableField(value="source_type")
    private Integer sourceType; // 来源,1-目标成本，2-材料档案，3-总计划
    @TableField(value="unit_id")
    private Long unitId; // 计量单位id
    @TableField(value="row_type")
    private Integer rowType; // 行分类,1-分类，2-材料

    @TableField(value="unit_m_id")
    private Long unitMId; // 计租单位id
    @TableField(value="unit_m_name")
    private String unitMName; // 计租单位名称

    public Long getUnitMId() {
        return unitMId;
    }

    public void setUnitMId(Long unitMId) {
        this.unitMId = unitMId;
    }

    public String getUnitMName() {
        return unitMName;
    }

    public void setUnitMName(String unitMName) {
        this.unitMName = unitMName;
    }

    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public Integer getRowType() {
        return rowType;
    }

    public void setRowType(Integer rowType) {
        this.rowType = rowType;
    }

    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }



    public Long getBatchId() {
        return batchId;
    }

    public void setBatchId(Long batchId) {
        this.batchId = batchId;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public Date getPlanUseTime() {
        return planUseTime;
    }

    public void setPlanUseTime(Date planUseTime) {
        this.planUseTime = planUseTime;
    }
    public String getStandard() {
        return standard;
    }

    public void setStandard(String standard) {
        this.standard = standard;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    
}

==> ejc-assistrmat-impl-3.0.0-20220929.120844-240-sources.jar: com/ejianc/business/assist/material/bean/MaterialBatchPlanDetailEntity.java <==
package com.ejianc.business.assist.material.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 周转材采购申请-清单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_assistmaterial_batch_plan_detail")
public class MaterialBatchPlanDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="batch_id")
    private Long batchId; // 批次计划主键
    @TableField(value="material_type_id")
    private Long materialTypeId; // 材料分类id
    @TableField(value="material_type_name")
    private String materialTypeName; // 材料分类名称
    @TableField(value="material_type_code")
    private String materialTypeCode; // 材料分类编码
    @TableField(value="material_id")
    private Long materialId; // 材料id
    @TableField(value="material_name")
    private String materialName; // 材料名称
    @TableField(value="material_code")
    private String materialCode; // 材料编码
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit")
    private String unit; // 计量单位
    @TableField(value="num")
    private BigDecimal num; // 计划总量
    @TableField(value="mny")
    private BigDecimal mny; // 暂估金额
    @TableField(value="plan_use_time")
    private Date planUseTime; // 计划开始使用时间
    @TableField(value="standard")
    private String standard; // 质量验收标准或要求
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="source_id")
    private Long sourceId; // 物资来源出业务Id
    @TableField(value="source_type")
    private Integer sourceType; // 来源,1-目标成本，2-材料档案，3-总计划
    @TableField(value="unit_id")
    private Long unitId; // 计量单位id
    @TableField(value="row_type")
    private Integer rowType; // 行分类,1-分类，2-材料

    @TableField(value="unit_m_id")
    private Long unitMId; // 计租单位id
    @TableField(value="unit_m_name")
    private String unitMName; // 计租单位名称

    @TableField(value="price")
    private BigDecimal price; // 单价
    @TableField(value="brand")
    private String brand; // 品牌

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public String getBrand() {
        return brand;
    }

    public void setBrand(String brand) {
        this.brand = brand;
    }

    public Long getUnitMId() {
        return unitMId;
    }

    public void setUnitMId(Long unitMId) {
        this.unitMId = unitMId;
    }

    public String getUnitMName() {
        return unitMName;
    }

    public void setUnitMName(String unitMName) {
        this.unitMName = unitMName;
    }

    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public Integer getRowType() {
        return rowType;
    }

    public void setRowType(Integer rowType) {
        this.rowType = rowType;
    }

    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }



    public Long getBatchId() {
        return batchId;
    }

    public void setBatchId(Long batchId) {
        this.batchId = batchId;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public Date getPlanUseTime() {
        return planUseTime;
    }

    public void setPlanUseTime(Date planUseTime) {
        this.planUseTime = planUseTime;
    }
    public String getStandard() {
        return standard;
    }

    public void setStandard(String standard) {
        this.standard = standard;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    
}
